@@ -495,3 +495,6 @@ class ResourceSet(object):
             self._store.remove((obj, self._predicate, self._subject._id))
         else:
             self._store.remove((self._subject._id, self._predicate, obj))
+
+    def any(self):
+        list(self._store.objects(self._subject._id, self._predicate))[0]
